package com.logicbig.example;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.jdbc.support.GeneratedKeyHolder;
import org.springframework.jdbc.support.KeyHolder;
import org.springframework.stereotype.Component;

import java.sql.PreparedStatement;
import java.util.List;

@Component
public class CustomerBean {
    @Autowired
    private JdbcTemplate jdbcTemplate;

    public void createCustomers() {
        String sql = "insert into CUSTOMER (NAME, PHONE, ADDRESS) values (?, ?, ?)";
        KeyHolder keyHolder = new GeneratedKeyHolder();

        jdbcTemplate.update(
                connection -> {
                    PreparedStatement ps = connection.prepareStatement(sql, new String[]{"ID"});
                    ps.setString(1, "Jake");
                    ps.setString(2, "234-333-627");
                    ps.setString(3, "345 Move Dr, Shine Hill");
                    return ps;
                }, keyHolder);

        Number key = keyHolder.getKey();
        System.out.println("Newly persisted customer generated id: " + key.longValue());
        System.out.println("-- loading customer by id --");
        System.out.println(loadCustomerById(key.longValue()));

    }

    public Customer loadCustomerById(long id) {
        List<Customer> customers = jdbcTemplate.query("select * from CUSTOMER where id =?",
                new Object[]{id}, (resultSet, i) -> {
                    return Customer.create(
                            resultSet.getLong("ID"),
                            resultSet.getString("NAME"),
                            resultSet.getString("PHONE"),
                            resultSet.getString("ADDRESS"));
                });

        if (customers.size() == 1) {
            return customers.get(0);
        }
        return null;
    }
}